Translate Toolkit 3.4.1 — Translate Toolkit 3.6.2 documentation

# Translate Toolkit 3.4.1

Released on 10 September 2021

This release contains improvements and bug fixes.

## Changes

### Formats and Converters

- Fluent

  - Fixed comments handling

- HTML

  - Avoid whitespace normalization for <pre>

  - Performance improvements

- RC

  - Fixed mixed newlines in generated files

  - Fixed handling comments inside a control

  - Fixed specific control blocks handling

## Contributors

This release was made possible by the following people:

Michal Čihař, Jack Grigg